redvox.api900.exceptions API documentation
Description: This module contains custom exceptions for API 900.

# Module `redvox.api900.exceptions`

This module contains custom exceptions for API 900.

Expand source code

    """
    This module contains custom exceptions for API 900.
    """

    class ReaderException(Exception):
        """Custom reader exception"""

    class WrappedRedvoxPacketException(ReaderException):
        """Exception for WrappedRedvoxPackets"""

    class ConcatenationException(WrappedRedvoxPacketException):
        """Exception for concatenating WrappedRedvoxPackets"""

## Classes

`class ConcatenationException (*args, **kwargs)`

  Exception for concatenating WrappedRedvoxPackets

  Expand source code

      class ConcatenationException(WrappedRedvoxPacketException):
          """Exception for concatenating WrappedRedvoxPackets"""

  ### Ancestors

  - WrappedRedvoxPacketException
  - ReaderException
  - builtins.Exception
  - builtins.BaseException
`class ReaderException (*args, **kwargs)`

  Custom reader exception

  Expand source code

      class ReaderException(Exception):
          """Custom reader exception"""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException

  ### Subclasses

  - WrappedRedvoxPacketException
`class WrappedRedvoxPacketException (*args, **kwargs)`

  Exception for WrappedRedvoxPackets

  Expand source code

      class WrappedRedvoxPacketException(ReaderException):
          """Exception for WrappedRedvoxPackets"""

  ### Ancestors

  - ReaderException
  - builtins.Exception
  - builtins.BaseException

  ### Subclasses

  - ConcatenationException